@@ -791,7 +791,7 @@ def membership_import_upload(request, template_name='memberships/import-upload-f
         form = UploadForm(request.POST, request.FILES)
         if form.is_valid():
             # reset the password_promt session
-            request.session['password_promt'] = False
+            del request.session['password_promt']
             cleaned_data = form.cleaned_data
             app = cleaned_data['app']
             interactive = cleaned_data['interactive']
@@ -1831,7 +1831,7 @@ def membership_export(request):
     if request.method == 'POST':
         if form.is_valid():
             # reset the password_promt session
-            request.session['password_promt'] = False
+            del request.session['password_promt']
             app = form.cleaned_data['app']
             export_id = run_export_task('memberships', 'membership', [], app)
             return redirect('export.status', export_id)
